@@ -520,7 +520,7 @@ class ConsumerThread(Thread):
         self.client_id = client_id
         self.kill = False
         self.serializer = serializer
-
+        self.amqp_credentials = amqp_credentials
         try:
             self.amqpconn = BrokerConnection(hostname=amqp_credentials.hostname,
                                        port=amqp_credentials.port,
@@ -673,7 +673,12 @@ class ConsumerThread(Thread):
             except Exception:
                 logger.exception('Exception: Lost Connection during Fetch in Consumer Thread')
                 self.amqpconn.close()
-                self.amqpconn.connect()
+                self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
+                                   port=self.amqp_credentials.port,
+                                   userid=self.amqp_credentials.username,
+                                   password=self.amqp_credentials.password,
+                                   virtual_host=self.amqp_credentials.vhost,
+                                   ssl=self.amqp_credentials.ssl)
 #===========================================================================
 class PublisherThread(Thread):
     """
@@ -762,7 +767,12 @@ class PublisherThread(Thread):
                 self.method_queue.insert(0, method_message)
                 try:
                     self.amqpconn.close()
-                    self.amqpconn.connect()
+                    self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
+                                   port=self.amqp_credentials.port,
+                                   userid=self.amqp_credentials.username,
+                                   password=self.amqp_credentials.password,
+                                   virtual_host=self.amqp_credentials.vhost,
+                                   ssl=self.amqp_credentials.ssl)
                 except Exception:
                     logger.exeption('Exception: During connection a broken AMQP Connection')
     
